Documentation
¶
Index ¶
- Constants
- Variables
- type FILE
- type Fpos_t
- type Off_t
- type Ptrdiff_t
- type Size_t
- type Ssize_t
- type Va_list
- type Wchar_t
- type X_G_fpos64_t
- type X_G_fpos_t
- type X_IO_FILE
- type X__FILE
- type X__blkcnt64_t
- type X__blkcnt_t
- type X__blksize_t
- type X__builtin_va_list
- type X__caddr_t
- type X__clock_t
- type X__clockid_t
- type X__daddr_t
- type X__dev_t
- type X__float128
- type X__fpos64_t
- type X__fpos_t
- type X__fsblkcnt64_t
- type X__fsblkcnt_t
- type X__fsfilcnt64_t
- type X__fsfilcnt_t
- type X__fsid_t
- type X__fsword_t
- type X__gid_t
- type X__gnuc_va_list
- type X__id_t
- type X__ino64_t
- type X__ino_t
- type X__int8_t
- type X__int16_t
- type X__int32_t
- type X__int64_t
- type X__int128_t
- type X__int_least8_t
- type X__int_least16_t
- type X__int_least32_t
- type X__int_least64_t
- type X__intmax_t
- type X__intptr_t
- type X__key_t
- type X__loff_t
- type X__mbstate_t
- type X__mode_t
- type X__nlink_t
- type X__off64_t
- type X__off_t
- type X__pid_t
- type X__quad_t
- type X__rlim64_t
- type X__rlim_t
- type X__sig_atomic_t
- type X__socklen_t
- type X__ssize_t
- type X__suseconds_t
- type X__syscall_slong_t
- type X__syscall_ulong_t
- type X__time_t
- type X__timer_t
- type X__u_char
- type X__u_int
- type X__u_long
- type X__u_quad_t
- type X__u_short
- type X__uid_t
- type X__uint8_t
- type X__uint16_t
- type X__uint32_t
- type X__uint64_t
- type X__uint128_t
- type X__uint_least8_t
- type X__uint_least16_t
- type X__uint_least32_t
- type X__uint_least64_t
- type X__uintmax_t
- type X__useconds_t
Constants ¶
const ( BUFSIZ = 8192 EOF = -1 FILENAME_MAX = 4096 FOPEN_MAX = 16 L_ctermid = 9 L_tmpnam = 20 P_tmpdir = "/tmp" SEEK_CUR = 1 SEEK_END = 2 SEEK_SET = 0 TMP_MAX = 238328 X_ATFILE_SOURCE = 1 X_BITS_STDIO_LIM_H = 1 X_BITS_TIME64_H = 1 X_BITS_TYPESIZES_H = 1 X_BITS_TYPES_H = 1 X_BSD_SIZE_T_ = 0 X_BSD_SIZE_T_DEFINED_ = 0 X_DEFAULT_SOURCE = 1 X_FEATURES_H = 1 X_FILE_OFFSET_BITS = 64 X_GCC_SIZE_T = 0 X_IOFBF = 0 X_IOLBF = 1 X_IONBF = 2 X_IO_EOF_SEEN = 0x0010 X_IO_ERR_SEEN = 0x0020 X_IO_USER_LOCK = 0x8000 X_LP64 = 1 X_POSIX_C_SOURCE = 200809 X_POSIX_SOURCE = 1 X_SIZET_ = 0 X_SIZE_T = 0 X_SIZE_T_ = 0 X_SIZE_T_DECLARED = 0 X_SIZE_T_DEFINED = 0 X_SIZE_T_DEFINED_ = 0 X_STDC_PREDEF_H = 1 X_STDIO_H = 1 X_SYS_CDEFS_H = 1 X_SYS_SIZE_T_H = 0 X_T_SIZE = 0 X_T_SIZE_ = 0 X_VA_LIST_DEFINED = 0 Linux = 1 Unix = 1 )
Variables ¶
var CAPI = map[string]struct{}{}
Functions ¶
This section is empty.
Types ¶
type FILE ¶
type FILE = X_IO_FILE /* FILE.h:7:25 */
The opaque type of streams. This is the definition used elsewhere.
type Fpos_t ¶
type Fpos_t = X__fpos64_t /* stdio.h:86:20 */
The type of the second argument to `fgetpos' and `fsetpos'.
type Off_t ¶
type Off_t = X__off64_t /* stdio.h:65:19 */
type Ssize_t ¶
type Ssize_t = X__ssize_t /* stdio.h:77:19 */
type Va_list ¶
type Va_list = X__gnuc_va_list /* stdio.h:52:24 */
type X_G_fpos64_t ¶
type X_G_fpos64_t = struct {
F__pos X__off64_t
F__state X__mbstate_t
} /* __fpos64_t.h:10:9 */
The tag name of this struct is _G_fpos64_t to preserve historic
C++ mangled names for functions taking fpos_t and/or fpos64_t arguments. That name should not be used in new code.
type X_G_fpos_t ¶
type X_G_fpos_t = struct {
F__pos X__off_t
F__state X__mbstate_t
} /* __fpos_t.h:10:9 */
The tag name of this struct is _G_fpos_t to preserve historic
C++ mangled names for functions taking fpos_t arguments. That name should not be used in new code.
type X_IO_FILE ¶
type X_IO_FILE = struct {
F_flags int32
F__ccgo_pad1 [4]byte
F_IO_read_ptr uintptr
F_IO_read_end uintptr
F_IO_read_base uintptr
F_IO_write_base uintptr
F_IO_write_ptr uintptr
F_IO_write_end uintptr
F_IO_buf_base uintptr
F_IO_buf_end uintptr
F_IO_save_base uintptr
F_IO_backup_base uintptr
F_IO_save_end uintptr
F_markers uintptr
F_chain uintptr
F_fileno int32
F_flags2 int32
F_old_offset X__off_t
F_cur_column uint16
F_vtable_offset int8
F_shortbuf [1]int8
F__ccgo_pad2 [4]byte
F_lock uintptr
F_offset X__off64_t
F_codecvt uintptr
F_wide_data uintptr
F_freeres_list uintptr
F_freeres_buf uintptr
F__pad5 Size_t
F_mode int32
F_unused2 [20]int8
} /* __FILE.h:4:1 */
type X__blkcnt64_t ¶
type X__blkcnt64_t = int64 /* types.h:180:30 */
type X__blkcnt_t ¶
type X__blkcnt_t = int64 /* types.h:179:28 */
Type to count number of disk blocks.
type X__builtin_va_list ¶
type X__builtin_va_list = uintptr /* <builtin>:46:14 */
type X__caddr_t ¶
type X__caddr_t = uintptr /* types.h:203:14 */
type X__clock_t ¶
type X__clock_t = int64 /* types.h:156:27 */ // Type of CPU usage counts.
type X__clockid_t ¶
type X__clockid_t = int32 /* types.h:168:29 */
Clock ID used in clock and timer functions.
type X__daddr_t ¶
type X__daddr_t = int32 /* types.h:164:27 */ // The type of a disk address.
type X__float128 ¶
type X__float128 = float64 /* <builtin>:47:21 */
type X__fpos64_t ¶
type X__fpos64_t = X_G_fpos64_t /* __fpos64_t.h:14:3 */
The tag name of this struct is _G_fpos64_t to preserve historic
C++ mangled names for functions taking fpos_t and/or fpos64_t arguments. That name should not be used in new code.
type X__fpos_t ¶
type X__fpos_t = X_G_fpos_t /* __fpos_t.h:14:3 */
The tag name of this struct is _G_fpos_t to preserve historic
C++ mangled names for functions taking fpos_t arguments. That name should not be used in new code.
type X__fsblkcnt64_t ¶
type X__fsblkcnt64_t = uint64 /* types.h:184:32 */
type X__fsblkcnt_t ¶
type X__fsblkcnt_t = uint64 /* types.h:183:30 */
Type to count file system blocks.
type X__fsfilcnt64_t ¶
type X__fsfilcnt64_t = uint64 /* types.h:188:32 */
type X__fsfilcnt_t ¶
type X__fsfilcnt_t = uint64 /* types.h:187:30 */
Type to count file system nodes.
type X__fsid_t ¶
type X__fsid_t = struct{ F__val [2]int32 } /* types.h:155:26 */ // Type of file system IDs.
type X__fsword_t ¶
type X__fsword_t = int64 /* types.h:191:28 */
Type of miscellaneous file system fields.
type X__gnuc_va_list ¶
type X__gnuc_va_list = X__builtin_va_list /* stdarg.h:40:27 */
type X__ino64_t ¶
type X__ino64_t = uint64 /* types.h:149:27 */ // Type of file serial numbers (LFS).
type X__int8_t ¶
type X__int8_t = int8 /* types.h:37:21 */
Fixed-size types, underlying types depend on word size and compiler.
type X__int16_t ¶
type X__int16_t = int16 /* types.h:39:26 */
type X__int32_t ¶
type X__int32_t = int32 /* types.h:41:20 */
type X__int64_t ¶
type X__int64_t = int64 /* types.h:44:25 */
type X__int128_t ¶ added in v1.3.0
type X__int_least8_t ¶
type X__int_least8_t = X__int8_t /* types.h:52:18 */
Smallest types with at least a given width.
type X__int_least16_t ¶
type X__int_least16_t = X__int16_t /* types.h:54:19 */
type X__int_least32_t ¶
type X__int_least32_t = X__int32_t /* types.h:56:19 */
type X__int_least64_t ¶
type X__int_least64_t = X__int64_t /* types.h:58:19 */
type X__intptr_t ¶
type X__intptr_t = int64 /* types.h:206:25 */
Duplicates info from stdint.h but this is used in unistd.h.
type X__loff_t ¶
type X__loff_t = X__off64_t /* types.h:202:19 */ // Type of file sizes and offsets (LFS).
These few don't really vary by system, they always correspond
to one of the other defined types.
type X__mbstate_t ¶
type X__mbstate_t = struct {
F__count int32
F__value struct{ F__wch uint32 }
} /* __mbstate_t.h:21:3 */
Conversion state information.
type X__nlink_t ¶
type X__nlink_t = uint64 /* types.h:151:27 */ // Type of file link counts.
type X__off64_t ¶
type X__off64_t = int64 /* types.h:153:27 */ // Type of file sizes and offsets (LFS).
type X__rlim64_t ¶
type X__rlim64_t = uint64 /* types.h:158:28 */ // Type for resource measurement (LFS).
type X__sig_atomic_t ¶
type X__sig_atomic_t = int32 /* types.h:214:13 */
C99: An integer type that can be accessed as an atomic entity,
even in the presence of asynchronous interrupts. It is not currently necessary for this to be machine-specific.
type X__socklen_t ¶
type X__socklen_t = uint32 /* types.h:209:23 */
Duplicate info from sys/socket.h.
type X__ssize_t ¶
type X__ssize_t = int64 /* types.h:193:27 */ // Type of a byte count, or error.
type X__suseconds_t ¶
type X__suseconds_t = int64 /* types.h:162:31 */ // Signed count of microseconds.
type X__syscall_slong_t ¶
type X__syscall_slong_t = int64 /* types.h:196:33 */
Signed long type used in system calls.
type X__syscall_ulong_t ¶
type X__syscall_ulong_t = uint64 /* types.h:198:33 */
Unsigned long type used in system calls.
type X__timer_t ¶
type X__timer_t = uintptr /* types.h:171:12 */
Timer ID returned by `timer_create'.
type X__u_quad_t ¶
type X__u_quad_t = uint64 /* types.h:64:27 */
type X__u_short ¶
type X__u_short = uint16 /* types.h:32:28 */
type X__uint8_t ¶
type X__uint8_t = uint8 /* types.h:38:23 */
type X__uint16_t ¶
type X__uint16_t = uint16 /* types.h:40:28 */
type X__uint32_t ¶
type X__uint32_t = uint32 /* types.h:42:22 */
type X__uint64_t ¶
type X__uint64_t = uint64 /* types.h:45:27 */
type X__uint128_t ¶ added in v1.3.0
type X__uint_least8_t ¶
type X__uint_least8_t = X__uint8_t /* types.h:53:19 */
type X__uint_least16_t ¶
type X__uint_least16_t = X__uint16_t /* types.h:55:20 */
type X__uint_least32_t ¶
type X__uint_least32_t = X__uint32_t /* types.h:57:20 */
type X__uint_least64_t ¶
type X__uint_least64_t = X__uint64_t /* types.h:59:20 */
type X__uintmax_t ¶
type X__uintmax_t = uint64 /* types.h:73:27 */
type X__useconds_t ¶
type X__useconds_t = uint32 /* types.h:161:30 */ // Count of microseconds.